@@ -4,7 +4,7 @@ use 5.008_001;
 use strict;
 use warnings;
 
-our $VERSION = '2.0006';
+our $VERSION = '2.0007';
 
 use Carp              ();
 use File::Spec        ();
@@ -153,6 +153,7 @@ sub options { # overridable
         verbose      => 1,
         warn_handler => undef,
         die_handler  => undef,
+        pre_process_handler => undef,
 
         %{ $self->parser_option },
         %{ $self->compiler_option },
@@ -395,6 +396,7 @@ sub _load_source {
     }
 
     my $source = $self->slurp_template($self->input_layer, $fullpath);
+    $source = $self->{pre_process_handler}->($source) if $self->{pre_process_handler};
     $self->{source}{$fi->{name}} = $source if _SAVE_SRC;
 
     my $asm = $self->compile($source,
@@ -655,7 +657,7 @@ Text::Xslate - Scalable template engine for Perl5
 
 =head1 VERSION
 
-This document describes Text::Xslate version 2.0006.
+This document describes Text::Xslate version 2.0007.
 
 =head1 SYNOPSIS
 
@@ -939,6 +941,24 @@ Specify the callback I<&cb> which is called on warnings.
 
 Specify the callback I<&cb> which is called on fatal errors.
 
+=item C<< pre_process_handler => \&cb >>
+
+Specify the callback I<&cb> which is called after templates are loaded from the disk
+in order to pre-process template.
+
+For example:
+
+    # Remove withespace from templates
+    my $tx = Text::Xslate->new(
+        pre_process_handler => sub {
+            my $text = shift;
+            $text=~s/\s+//g;
+            return $text;
+        }
+    );
+
+The first argument is the template text string, which can be both B<text strings> and C<byte strings>.
+
 =back
 
 =head3 B<< $tx->render($file, \%vars) :Str >>
